@@ -75,7 +75,7 @@ class LaunchHandler(APIHandler):
         except KeyError:
             self.set_status(404)
         else:
-            remove_proxy_uri(state['base_uri'])
+            remove_proxy_uri(state['root_uri'])
             process = state['process']
             terminate_process(process.pid)
             del LAUNCH_STATE_BY_FOLDER[relative_folder]
@@ -120,7 +120,10 @@ def clean():
         process_id = process.pid
         terminate_process(process_id)
         L.debug('terminating process %s for %s', process.pid, state)
-    rmtree(FOLDER_BY_NAME['root'])
+    try:
+        rmtree(FOLDER_BY_NAME['root'])
+    except OSError:
+        pass
 
 
 LAUNCH_STATE_BY_FOLDER = {}
